@@ -4,14 +4,19 @@ from sklearn.metrics import accuracy_score
 from sklearn.metrics import confusion_matrix
 import pandas as pd
 
-def rolling_forecasting(forecasting_model, X, y, n=252, s=63, method = 'standard', display = False, **kwargs):
+def rolling_forecasting(forecasting_model, X, y, n=252, s=63, s_eval= None, method = 'standard', display = False, **kwargs):
     assert X.shape[0] == y.shape[0]
     idx = X.index
     forecasting_series = pd.Series(index=idx, name='prediction')
-    if n is None:
+
+    if n is None and s_eval is None:
         roll = rolling._ExpandingRollingMechanism(idx, s=s)
-    else:
+    if n is None and s_eval is not None:
+        roll = rolling._ExpandingEvalRollingMechanism(idx, s=s, s_eval = s_eval)
+    if n is not None and s_eval is None :
         roll = rolling._RollingMechanism(idx, n=n, s=s)
+    if n is not None and s_eval is not None:
+        roll = rolling._EvalRollingMechanism(idx, n=n, s=s, s_eval = s_eval)
 
     for slice_n, slice_s in roll():
         # Select X
